class HuffmanInterface:
    def compressFile(self, path: str) -> dict:
        """Compress the file provided in parameter.

        Args:
            path (str): path of the file to compress
        """
        pass

    def compress(self, text: str) -> dict:
        """Compress the text provided in parameter

        Args:
            text (str): text to compress
        """
        pass
